@@ -32,11 +32,17 @@
 
 import os
 import sys
+import yaml
 
 from .common import MANIFEST_FILE, STACK_FILE, ROS_STACK, ResourceNotFound
 from .environment import get_ros_paths, get_ros_home
 from .manifest import parse_manifest_file, InvalidManifest
 
+# disabling reading the .rospack_cache for now as the Fuerte codebase
+# doesn't invoke rospack/stack as promisciously as before.  This means
+# the cache is often invalid now.
+ROSPACK_CACHE_ENABLED = False
+
 def _read_rospack_cache(cache_path, cache, ros_paths):
     """
     Read in rospack/rosstack cache data into cache. On-disk cache
@@ -51,6 +57,8 @@ def _read_rospack_cache(cache_path, cache, ros_paths):
       ``False`` otherwise.  If ``False``, *cache* will be emptied,
       ``bool``
     """
+    if not ROSPACK_CACHE_ENABLED:
+        return False
     if not os.path.exists(cache_path):
         return False
 
@@ -438,6 +446,18 @@ def get_stack_version_by_dir(stack_dir):
 
     :returns: version number of stack, or None if stack is unversioned, ``str``
     """
+    # REP TODO: stack.yaml now has precedence
+    catkin_stack_filename = os.path.join(stack_dir, 'stack.yaml')
+    if os.path.isfile(catkin_stack_filename):
+        with open(catkin_stack_filename) as f:
+            try:
+                d = yaml.load(f)
+                if 'Version' in d:
+                    return d['Version']
+            except:
+                raise
+                pass
+    
     # REP 109: check for <version> tag first, then CMakeLists.txt
     manifest_filename = os.path.join(stack_dir, STACK_FILE)
     if os.path.isfile(manifest_filename):
